@@ -457,4 +457,7 @@ class Contract(BaseContent):
         else:
             return str(int(odd_weeks)) + '/' + str(int(even_weeks))
 
+    def is_contract(self):
+        return True
+
 registerType(Contract, config.PROJECTNAME)
